==> kubernetes-model-1.0.58-sources.jar: annotations/io/fabric8/kubernetes/api/model/extensions/RollingUpdateDeploymentFluent.java <==
package io.fabric8.kubernetes.api.model.extensions;

import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.model.IntOrString;
import com.fasterxml.jackson.annotation.JsonProperty;
import javax.validation.Valid;
import java.lang.String;
import java.lang.Object;
import java.util.Map;
import com.fasterxml.jackson.annotation.JsonIgnore;
import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.IntOrStringFluent;
import io.fabric8.kubernetes.api.model.IntOrStringBuilder;
import com.fasterxml.jackson.databind.JsonSerializer;
import com.fasterxml.jackson.core.JsonGenerator;
import com.fasterxml.jackson.databind.SerializerProvider;
import java.lang.Override;
import com.fasterxml.jackson.databind.JsonDeserializer;
import com.fasterxml.jackson.core.JsonParser;
import com.fasterxml.jackson.databind.DeserializationContext;

public interface RollingUpdateDeploymentFluent<A extends RollingUpdateDeploymentFluent<A>> extends Fluent<A>{


    public IntOrString getMaxSurge();
    public A withMaxSurge(IntOrString maxSurge);
    public RollingUpdateDeploymentFluent.MaxSurgeNested<A> withNewMaxSurge();
    public RollingUpdateDeploymentFluent.MaxSurgeNested<A> withNewMaxSurgeLike(IntOrString item);
    public RollingUpdateDeploymentFluent.MaxSurgeNested<A> editMaxSurge();
    public A withNewMaxSurge(String strVal);
    public A withNewMaxSurge(Integer intVal);
    public IntOrString getMaxUnavailable();
    public A withMaxUnavailable(IntOrString maxUnavailable);
    public RollingUpdateDeploymentFluent.MaxUnavailableNested<A> withNewMaxUnavailable();
    public RollingUpdateDeploymentFluent.MaxUnavailableNested<A> withNewMaxUnavailableLike(IntOrString item);
    public RollingUpdateDeploymentFluent.MaxUnavailableNested<A> editMaxUnavailable();
    public A withNewMaxUnavailable(String strVal);
    public A withNewMaxUnavailable(Integer intVal);

    public interface MaxSurgeNested<N> extends Nested<N>,IntOrStringFluent<RollingUpdateDeploymentFluent.MaxSurgeNested<N>>{

        
    public N and();    public N endMaxSurge();
}
    public interface MaxUnavailableNested<N> extends Nested<N>,IntOrStringFluent<RollingUpdateDeploymentFluent.MaxUnavailableNested<N>>{

        
    public N endMaxUnavailable();    public N and();
}


}

==> kubernetes-model-1.0.60-sources.jar: annotations/io/fabric8/kubernetes/api/model/extensions/RollingUpdateDeploymentFluent.java <==
package io.fabric8.kubernetes.api.model.extensions;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.model.IntOrString;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import com.fasterxml.jackson.databind.JsonSerializer;
import java.lang.String;
import com.fasterxml.jackson.databind.JsonDeserializer;
import io.fabric8.kubernetes.api.model.IntOrStringBuilder;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.core.JsonGenerator;
import com.fasterxml.jackson.databind.DeserializationContext;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.databind.SerializerProvider;
import java.lang.Override;
import io.sundr.builder.annotations.Buildable;
import com.fasterxml.jackson.core.JsonParser;
import javax.annotation.Generated;
import io.fabric8.kubernetes.api.builder.Fluent;
import lombok.EqualsAndHashCode;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import io.fabric8.kubernetes.api.model.IntOrStringFluent;
import java.lang.Integer;
import javax.validation.Valid;
import java.lang.Object;
import lombok.ToString;
import java.util.Map;

public interface RollingUpdateDeploymentFluent<A extends RollingUpdateDeploymentFluent<A>> extends Fluent<A>{


    public IntOrString getMaxSurge();
    public A withMaxSurge(IntOrString maxSurge);
    public RollingUpdateDeploymentFluent.MaxSurgeNested<A> withNewMaxSurge();
    public RollingUpdateDeploymentFluent.MaxSurgeNested<A> withNewMaxSurgeLike(IntOrString item);
    public RollingUpdateDeploymentFluent.MaxSurgeNested<A> editMaxSurge();
    public RollingUpdateDeploymentFluent.MaxSurgeNested<A> editOrNewMaxSurge();
    public RollingUpdateDeploymentFluent.MaxSurgeNested<A> editOrNewMaxSurgeLike(IntOrString item);
    public A withNewMaxSurge(Integer intVal);
    public A withNewMaxSurge(String strVal);
    public IntOrString getMaxUnavailable();
    public A withMaxUnavailable(IntOrString maxUnavailable);
    public RollingUpdateDeploymentFluent.MaxUnavailableNested<A> withNewMaxUnavailable();
    public RollingUpdateDeploymentFluent.MaxUnavailableNested<A> withNewMaxUnavailableLike(IntOrString item);
    public RollingUpdateDeploymentFluent.MaxUnavailableNested<A> editMaxUnavailable();
    public RollingUpdateDeploymentFluent.MaxUnavailableNested<A> editOrNewMaxUnavailable();
    public RollingUpdateDeploymentFluent.MaxUnavailableNested<A> editOrNewMaxUnavailableLike(IntOrString item);
    public A withNewMaxUnavailable(Integer intVal);
    public A withNewMaxUnavailable(String strVal);

    public interface MaxSurgeNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,IntOrStringFluent<RollingUpdateDeploymentFluent.MaxSurgeNested<N>>{

        
    public N and();    public N endMaxSurge();
}
    public interface MaxUnavailableNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,IntOrStringFluent<RollingUpdateDeploymentFluent.MaxUnavailableNested<N>>{

        
    public N and();    public N endMaxUnavailable();
}


}
